@@ -2,6 +2,13 @@
 ##'
 ##' @param object An `etwfe` model object.
 ##' @param type Character. The desired type of post-estimation aggregation.
+##' @param post_only Logical. Only keep post-treatment effects. All
+##'   pre-treatment effects will be zero as a mechanical result of ETWFE's 
+##'   estimation setup, so the default is to drop these nuisance rows from
+##'   the dataset. But you may want to keep them for presentation reasons
+##'   (e.g., plotting an event-study); though be warned that this is 
+##'   strictly performative. This argument will only be evaluated if
+##'   `type = "event"`.
 ##' @param ... Additional arguments passed to 
 ##' [`marginaleffects::marginaleffects`].
 ##' @return A marginaleffects object.
@@ -11,6 +18,7 @@
 emfx = function(
     object,
     type = c("simple", "group", "calendar", "event"),
+    post_only = TRUE,
     ...
 ) {
   
@@ -18,9 +26,15 @@ emfx = function(
   type = match.arg(type)
   gvar = attributes(object)[["etwfe"]][["gvar"]]
   tvar = attributes(object)[["etwfe"]][["tvar"]]
+  gref = attributes(object)[["etwfe"]][["gref"]]
+  tref = attributes(object)[["etwfe"]][["tref"]]
   
   dat = eval(object$call$data, object$call_env)
-  if (".Dtreat" %in% names(dat)) dat = dat[dat[[".Dtreat"]]==1L, , drop = FALSE]
+  if (type=="event" & !post_only) {
+    dat = dat[dat[[gvar]] != gref, , drop = FALSE]
+  } else {
+    if (".Dtreat" %in% names(dat)) dat = dat[dat[[".Dtreat"]], , drop = FALSE]
+  }
   
   if (type=="simple") by_var = ".Dtreat"
   if (type=="group") by_var = gvar
